magneticalc.QtWidgets2.QDialog2.QDialog2

# ``magneticalc`.`QtWidgets2`.`QDialog2`.`QDialog2``

class documentation

`class QDialog2(QDialog, QLayouted):`

Known subclasses: `magneticalc.About_Dialog.About_Dialog`, `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog`, `magneticalc.Constraint_Editor.Constraint_Editor`, `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog`, `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog`, `magneticalc.QMessageBox2.QMessageBox2`, `magneticalc.Usage_Dialog.Usage_Dialog`

Constructor: `QDialog2(title, width)`

View In Hierarchy

QDialog2 class.

Method | `__init__` | Initializes QDialog2.
Method | `show` | Shows this dialog.
Method | `showEvent` | Gets called when the dialog is opened.
Instance Variable | `user_accepted` | Undocumented

Inherited from `QLayouted`:

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, title: `str | None` = None, width: `int | None` = None):
overrides `magneticalc.QtWidgets2.QLayouted.QLayouted.__init__`
overridden in `magneticalc.About_Dialog.About_Dialog`, `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog`, `magneticalc.Constraint_Editor.Constraint_Editor`, `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog`, `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog`, `magneticalc.QMessageBox2.QMessageBox2`, `magneticalc.Usage_Dialog.Usage_Dialog`

Initializes QDialog2.

Parameters
title: `str | None` | Title
width: `int | None` | Width

def show(self):

Shows this dialog.

def showEvent(self, event: `QShowEvent`):
overridden in `magneticalc.About_Dialog.About_Dialog`, `magneticalc.Constraint_Editor.Constraint_Editor`

Gets called when the dialog is opened.

Parameters
event: `QShowEvent` | QShowEvent

user_accepted =

Undocumented